@@ -20,8 +20,14 @@ def register():
     else:
         os.environ['QML2_IMPORT_PATH'] = directory
 
-    qmlRegisterType(QAudio, 'soloman', 1, 0, 'SAudio')
-    qmlRegisterType(QVideo, 'soloman', 1, 0, 'QVideo')
+    # Delete the contents of our Temp folder
+    path = os.path.join(os.environ['TEMP'], 'soloman', 'converts')
+    if os.path.exists(path):
+        print('apth: ', path)
+        os.system('RD "' + path + '" /S /Q')
+
+    qmlRegisterType(QAudio, 'soloman', 2, 1, 'SAudio')
+    qmlRegisterType(QVideo, 'soloman', 2, 1, 'QVideo')
 
 
 register()
